@@ -534,7 +534,6 @@ function widget.new(args)
         end)
     end
 
-
     --- Add hotkey descriptions for third-party applications.
     -- @tparam table hotkeys Table with bindings,
     -- see `awful.hotkeys_popup.key.vim` as an example.
@@ -556,6 +555,13 @@ function widget.new(args)
         self:_sort_hotkeys(self._additional_hotkeys)
     end
 
+    --- Add hotkey group rules for third-party applications.
+    -- @tparam string group hotkeys group name,
+    -- @tparam table data rule data for the group
+    -- see `awful.hotkeys_popup.key.vim` as an example.
+    function widget_instance:add_group_rules(group, data)
+        self.group_rules[group] = data
+    end
 
     return widget_instance
 end
@@ -582,6 +588,15 @@ function widget.add_hotkeys(...)
     return get_default_widget():add_hotkeys(...)
 end
 
+--- Add hotkey group rules for third-party applications
+-- (default widget instance will be used).
+-- @tparam string group rule group name,
+-- @tparam table data rule data for the group
+-- see `awful.hotkeys_popup.key.vim` as an example.
+function widget.add_group_rules(group, data)
+    return get_default_widget():add_group_rules(group, data)
+end
+
 return widget
 
 -- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
