@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- A simple button widget.
 -- @usage local button = awful.widget.button()
--- button:buttons(awful.util.table.join(
+-- button:buttons(gears.table.join(
 --     button:buttons(),
 --     awful.button({}, 1, nil, function ()
 --         print("Mouse was clicked")
@@ -45,7 +45,8 @@ function button.new(args)
         orig_set_image(self, img_release)
     end
     w:set_image(args.image)
-    w:buttons(abutton({}, 1, function () orig_set_image(w, img_press) end, function () orig_set_image(w, img_release) end))
+    w:buttons(abutton({}, 1, function () orig_set_image(w, img_press) end,
+                             function () orig_set_image(w, img_release) end))
 
     w:connect_signal("mouse::leave", function(self) orig_set_image(self, img_release) end)
 
