@@ -5,12 +5,12 @@
 --![Usage example](../images/AUTOGEN_wibox_widget_defaults_textbox.svg)
 --
 -- @usage
---wibox.widget{
---    markup = 'This <i>is</i> a <b>textbox</b>!!!',
---    align  = 'center',
---    valign = 'center',
---    widget = wibox.widget.textbox
---}
+-- wibox.widget{
+--     markup = 'This <i>is</i> a <b>textbox</b>!!!',
+--     align  = 'center',
+--     valign = 'center',
+--     widget = wibox.widget.textbox
+-- }
 -- @author Uli Schlachter
 -- @author dodo
 -- @copyright 2010, 2011 Uli Schlachter, dodo
@@ -21,7 +21,7 @@ local base = require("wibox.widget.base")
 local gdebug = require("gears.debug")
 local beautiful = require("beautiful")
 local lgi = require("lgi")
-local util = require("awful.util")
+local gtable = require("gears.table")
 local Pango = lgi.Pango
 local PangoCairo = lgi.PangoCairo
 local setmetatable = setmetatable
@@ -128,7 +128,7 @@ end
 --- Set the text of the textbox (with
 -- [Pango markup](https://developer.gnome.org/pango/stable/PangoMarkupFormat.html)).
 -- @tparam string text The text to set. This can contain pango markup (e.g.
---   `<b>bold</b>`). You can use `awful.util.escape` to escape
+--   `<b>bold</b>`). You can use `gears.string.escape` to escape
 --   parts of it.
 -- @treturn[1] boolean true
 -- @treturn[2] boolean false
@@ -156,7 +156,7 @@ end
 -- [Pango markup](https://developer.gnome.org/pango/stable/PangoMarkupFormat.html)).
 -- @property markup
 -- @tparam string text The text to set. This can contain pango markup (e.g.
---   `<b>bold</b>`). You can use `awful.util.escape` to escape
+--   `<b>bold</b>`). You can use `gears.string.escape` to escape
 --   parts of it.
 -- @see text
 
@@ -273,7 +273,7 @@ end
 local function new(text, ignore_markup)
     local ret = base.make_widget(nil, nil, {enable_properties = true})
 
-    util.table.crush(ret, textbox, true)
+    gtable.crush(ret, textbox, true)
 
     ret._private.dpi = -1
     ret._private.ctx = PangoCairo.font_map_get_default():create_context()
